import java.io.*;
import java.net.*;
import java.security.*;
import javax.crypto.*;

public class AuthenticatorSecuredComm {
    private Socket                   socket;
    private SecretKey                secretKey;
    private AuthenticatorHandShaking ahs;
    private ObjectInputStream        ois;
    private ObjectOutputStream       oos;
    private AuthenticatorKeyPair     akp;

    public AuthenticatorSecuredComm(Socket s, AuthenticatorKeyPair ck) {
        socket = s;
        akp = ck;
    }

    public boolean init() {
        try {
            oos = new ObjectOutputStream(socket.getOutputStream());
            oos.flush();
            ois = new ObjectInputStream(socket.getInputStream());

            ahs = new AuthenticatorHandShaking(ois, oos, akp);
            if (!ahs.init()) return false;

            secretKey = ahs.getSecretKey();
            return true;
        } catch (Exception ex) {
            System.err.println("AuthenticatorSecuredComm.init() Exception-> " + ex);
            return false;
        }
    }

    public SecretKey getSecretKey() {
        return this.secretKey;
    }

    public ObjectInputStream getObjectInputStream() {
        return ois;
    }

    public void done() {
        try { 
            oos.close();
            ois.close();
            socket.close();
        } catch (Exception ex) {
            System.err.println("AuthenticatorSecuredComm Exception-> " + ex);
        }
    }
}
